/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.util;

import java.io.File;
import java.io.FileFilter;
import java.io.IOException;
import org.openide.filesystems.FileObject;
import org.openide.util.Exceptions;

/**
 * 
 * @author Gerben Feenstra
 */
public class FileUtil {

    /**
     * Completely remove a directory and its content.
     * 
     * TODO: EXCEPTION HANDLING?
     * 
     * @param dir Directory to completely remove
     */
    public static void removeTree(File dir) {
        assert (dir != null);
        assert (dir.exists());

        // Find subdirs in specified dir
        File[] subdirs = dir.listFiles(new FileFilter() {

            @Override
            public boolean accept(File f) {
                if (f.isDirectory()) {
                    return true;
                }
                return false;
            }
        });

        // Recursive call to remove subdir and content
        for (File subdir : subdirs) {
            removeTree(subdir);
            subdir.delete();
        }

        // Find files in specified dir
        File[] files = dir.listFiles(new FileFilter() {

            @Override
            public boolean accept(File f) {
                if (f.isFile()) {
                    return true;
                }
                return false;
            }
        });

        // Remove files from dir
        for (File f : files) {
            f.delete();
        }

        // Remove the directory itself
        dir.delete();
    }

    /**
     * Retrieve and return the path of the current module
     * Creates and returns the real (full) path as File object of the module + specified path inside the module
     * 
     * @param packagePath For example: BeanTestUtils.getPath("/src/main/java");
     * @return For example: D:\projecten\agrosense~core\model\src\main\java
     */
    public static String getPath(String packagePath) {
        File currentpathFile = new File(".");
        String currentpathString = "";
        try {
            currentpathString = currentpathFile.getCanonicalPath();

        } catch (IOException ex) {
            Exceptions.printStackTrace(ex);
        }
        packagePath = "src.main.java." + packagePath;
        //nl.cloudfarming.client.model.Field
                

        return packagePath.replace('.', File.separatorChar);
    }
    
    /**
     * Touching file changes its lastModified date record.
     * <p>
     * Works only for existing files (not directories)
     * </p>
     * @param file
     * @return {@code true} if success, {@false} is touch failed.
     * 
     * 
     */
    public static boolean touch(File file) throws IOException {
        if (file != null && file.exists() && file.isFile()) {
            return file.setLastModified(System.currentTimeMillis());
        } else {
            return false;
        }
    }
    
    public static boolean touch(FileObject fileObject) throws IOException {
        return touch(org.openide.filesystems.FileUtil.toFile(fileObject));
    }
      
}
